---
layout: page
title: ksqlDB Overview
tagline: What is ksqlDB?
description: Learn about ksqlDB, the event streaming database for creating stream processing applications with Apache Kafka®.
keywords: ksqldb
---

[ksqlDB](https://ksqldb.io/) is an event streaming database purpose-built to help developers create
stream processing applications on top of {{ site.aktm }}.

## Try it

<div class="cards">
  <div class="card">
    <strong>Quickstarts</strong>
    <ul class="card-items">
      <li><a href="https://ksqldb.io/quickstart.html">Standalone quickstart</a></li>
    </ul>
  </div>

  <div class="card">
    <strong>How-to guides</strong>
    <ul class="card-items">
      <li><a href="/how-to-guides/query-structured-data/">Structured data</a></li>
      <li><a href="/how-to-guides/use-connector-management/">Connector management</a></li>
      <li><a href="/how-to-guides/create-a-user-defined-function/">User-defined functions</a></li>
      <li><a href="/how-to-guides/substitute-variables/">Variables</a></li>
    </ul>
    <small><a href="/how-to-guides/" class="card-more">More →</a></small>
  </div>

  <div class="card">
    <strong>Tutorials</strong>
    <ul class="card-items">
      <li><a href="/tutorials/materialized/">Materialized cache</a></li>
      <li><a href="/tutorials/etl/">Streaming ETL pipeline</a></li>
      <li><a href="/tutorials/event-driven-microservice/">Event-driven microservice</a></li>
    </ul>
    <small><a href="/tutorials/" class="card-more">More →</a></small>
  </div>
</div>

## Learn

<div class="cards">
  <div class="card">
    <strong>How it works</strong>
    <ul class="card-items">
      <li><a href="https://www.confluent.io/blog/how-real-time-stream-processing-works-with-ksqldb/">SQL Stream processing</a></li>
      <li><a href="https://www.confluent.io/blog/how-real-time-materialized-views-work-with-ksqldb/">Materialized views</a></li>
      <li><a href="https://www.confluent.io/blog/how-real-time-stream-processing-safely-scales-with-ksqldb/">Scaling and fault tolerance</a></li>
    </ul>
  </div>

  <div class="card">
    <strong>Concepts</strong>
    <ul class="card-items">
      <li><a href="/overview/apache-kafka-primer/">Apache Kafka primer</a></li>
      <li><a href="/concepts/stream-processing/">Stream processing</a></li>
      <li><a href="/concepts/time-and-windows-in-ksqldb-queries/">Time and windowing</a></li>
      <li><a href="/concepts/connectors/">Connectors</a></li>
    </ul>
    <small><a href="/concepts/" class="card-more">More →</a></small>
  </div>

  <div class="card">
    <strong>How it's used</strong>
    <ul class="card-items">
      <li><a href="https://www.confluent.io/blog/real-time-data-replication-with-ksqldb/">Real-time data replication</a></li>
      <li><a href="https://www.confluent.io/blog/how-pushowl-uses-ksqldb-to-scale-analytics-and-reporting-use-cases/">Real-time analytics</a></li>
      <li><a href="https://www.confluent.io/blog/real-time-business-intelligence-using-ksqldb">Business intelligence</a></li>
      <li><a href="https://www.confluent.io/blog/broadcom-uses-ksqldb-to-modernize-machine-learning-anomaly-detection/">Anomaly detection</a></li>
    </ul>
    <small><a href="https://ksqldb.io/news-and-community.html" class="card-more">More →</a></small>
  </div>
</div>

## Watch

<div class="cards">
  <div class="card">
    <strong>Intros</strong>
    <ul class="card-items">
      <li><a href="https://www.youtube.com/watch?v=-kFU6mCnOFw">Stream processing fundamentals</a></li>
      <li><a href="https://www.youtube.com/watch?v=SHKjuN2iXyk">Ask Confluent, ksqlDB overview</a></li>
      <li><a href="https://www.youtube.com/watch?v=7mGBxG2NhVQ">An introduction to ksqlDB</a></li>
    </ul>
  </div>

  <div class="card">
    <strong>Demos</strong>
    <ul class="card-items">
      <li><a href="https://www.youtube.com/watch?v=D5QMqapzX8o">Building a movie rating app</a></li>
      <li><a href="https://www.youtube.com/watch?v=4odZGWl-yZo">Stream data from AWS to Azure</a></li>
      <li><a href="https://www.youtube.com/watch?v=ad02yDTAZx0">Transform and sink events to JDBC</a></li>
    </ul>
  </div>
</div>
